﻿using MediatR;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using NetworkResurrector.Application.Commands;
using NetworkResurrector.Application.Queries;
using System.Threading.Tasks;

namespace NetworkResurrector.Api.Controllers
{
    [Authorize]
    [ApiController]
    [Route("resurrector")]
    public class ResurrectorController : ControllerBase
    {
        private readonly IMediator _mediator;

        public ResurrectorController(IMediator mediator)
        {
            _mediator = mediator;
        }

        [AllowAnonymous]
        [HttpGet("token/{userName}/{password}")]
        public async Task<IActionResult> GetToken([FromRoute] GetToken.Query query)
        {
            var result = await _mediator.Send(query);
            return Ok(result);
        }

        [HttpGet("validate-token")]
        public IActionResult ValidateToken()
        {
            return Ok("Valid");
        }

        [HttpPost("wake")]
        public async Task<IActionResult> WakeMachine([FromBody] WakeMachine wakeMachine)
        {
            var result = await _mediator.Send(wakeMachine);
            return Ok(result);
        }

        [HttpPost("ping")]
        public async Task<IActionResult> PingMachine([FromBody] PingMachine pingMachine)
        {
            var result = await _mediator.Send(pingMachine);
            return Ok(result);
        }

        [HttpPost("shutdown")]
        public async Task<IActionResult> ShutdownMachine([FromBody] ShutdownMachine shutdownMachine)
        {
            var result = await _mediator.Send(shutdownMachine);
            return Ok(result);
        }
    }
}
